#!/bin/sh
# set -x

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Upgrade Monitor 6.0.0 to 6.0.1
# ************************************************************************

#set defaults 
WARN_ONLY=no
START_TIME=`date` 
MY_DIR=`pwd`
LOGS=$MY_DIR/install/logs
COPYFILES_OUT=$LOGS/copy_Files.out
PROFILE_NAME=dashboard
WAS_HOME=/usr/IBM/WebSphere/AppServer
WPS_HOME=/usr/IBM/WebSphere/PortalServer
PROFILE_HOME=/usr/IBM/WebSphere/AppServer/profiles/$PROFILE_NAME
CELL_NAME=`hostname -s`Node01Cell
NODE=Node01
PORTAL_SERVER=WebSphere_Portal
ADMIN_ID=wpsadmin
ADMIN_PW=wpsadmin
CONFIG_HOST=localhost
CONFIG_PORT=9081
ABX_HOME=/usr/IBM/DB2Alphablox
ABX_HOST=localhost
ABX_TELNET_PORT=20023
ABX_ADMIN_ID=admin
ABX_ADMIN_PW=password
ABX_THEME=wbmonitor
SET_ABX_DEFAULT_THEME=yes
SET_WPS_DEFAULT_THEME=yes
WELCOME_PAGE=no
CONFIG_URL=http://$CONFIG_HOST:$CONFIG_PORT/wps/config

PROFILE_PROMPT="Type the path to the WebSphere profile that the contains the Portal Server"
PORTAL_HOME_PROMPT="Type the path to the Portal Server installation directory"
WAS_HOME_PROMPT="Type the path to the WebSphere Server installation directory"
ABX_HOME_PROMPT="Type the path to the DB2 AlphaBlox installation directory"
CELL_PROMPT="Type the WebSphere cell name that contains the WebSphere Portal node"
CONFIG_PORT_PROMPT="Type the port number used to access the WebSphere Portal configuration utility"
WPS_PW_PROMPT="Type the password for the Portal Admin user"
ABX_PW_PROMPT="Type the password for the DB2 Alphablox Admin user"


finished()
{
  echo BEGIN: $START_TIME
  echo END: `date`
  exit $1
}

cmdFailed()
{
  echo error: \'$CMD\' returned $1
  if [ $WARN_ONLY = "yes" ]
  then
    return $1
  fi 
  finished 8
}

checkCmdErr()
{
  if [ $1 -ne 0 ]  
  then
    cmdFailed $1
  fi
}

getWasVars()
{
# get was variables
echo $WAS_HOME_PROMPT [enter=$WAS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WAS_HOME=$RESPONSE
fi
if ! [ -d $WAS_HOME ]
then 
   echo error: $WAS_HOME does NOT exist
   finished 8
fi
echo $PROFILE_PROMPT [enter=$PROFILE_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   PROFILE_HOME=$RESPONSE
fi
if ! [ -d $PROFILE_HOME ]
then 
   echo error: $PROFILE_HOME does NOT exist
   finished 8
fi
}

getPortalVars()
{
# get portal variables
echo $PORTAL_HOME_PROMPT [enter=$WPS_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   WPS_HOME=$RESPONSE
fi
if ! [ -d $WPS_HOME ]
then 
   echo errror: $WPS_HOME does NOT exist
   finished 8
fi
echo $WPS_PW_PROMPT [enter=$ADMIN_PW ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ADMIN_PW=$RESPONSE
fi
echo $CELL_PROMPT [enter=$CELL_NAME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   CELL_NAME=$RESPONSE
fi
}

getAlphabloxVars()
{
# get alaphablox variables
echo $ABX_HOME_PROMPT [enter=$ABX_HOME ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ABX_HOME=$RESPONSE
fi
if ! [ -d $ABX_HOME ]
then 
   echo $ABX_HOME does NOT exist
   finished 8
fi
echo $ABX_PW_PROMPT [enter=$ABX_ADMIN_PW ]: 
read RESPONSE
if [ "$RESPONSE" != "" ] 
then
   ABX_ADMIN_PW=$RESPONSE
fi
}

copyFiles()
{
echo Copying files...
CMD="cp -f files/dashboardclient.war $WPS_HOME/installableApps" 
$CMD >$COPYFILES_OUT 2>&1
checkCmdErr $?
CMD="cp -f  jars/*.* $WAS_HOME/lib"
$CMD >>$COPYFILES_OUT 2>&1
checkCmdErr $?
CMD="cp -f  files/MON.product $WAS_HOME/properties/version" 
$CMD >>$COPYFILES_OUT 2>&1
checkCmdErr $?
# ...copy our Alphablox theme files to Alphablox
CMD="cp -f -R themes/wbmonitor $ABX_THEME_HOME"/ 
$CMD  >>$COPYFILES_OUT 2>&1
checkCmdErr $?
# ...copy portal shared nls files
CMD="cp -f -R themes/nls $WPS_HOME/shared/app/" 
$CMD  >>$COPYFILES_OUT 2>&1
checkCmdErr $?
# ...copy the built dashboard war files to the cell?
CMD="cp -f -R themes/war $PROFILE_HOME/installedApps/$CELL_NAME/wps.ear" 
$CMD  >>$COPYFILES_OUT 2>&1
checkCmdErr $?
# ...copy the wbi mon .gif files to abx theme directory 
CMD="cp -f  $ABX_THEME_HOME/wbmonitor/i/brand.gif $ABX_THEME_HOME/i/brand.gif"
$CMD  >>$COPYFILES_OUT 2>&1
checkCmdErr $?
CMD="cp -f  $ABX_THEME_HOME/wbmonitor/i/logo.gif $ABX_THEME_HOME/../../system/AlphabloxPlatform/AlphabloxServer/images/logo.gif" 
$CMD  >>$COPYFILES_OUT 2>&1
checkCmdErr $?
}


getWasVars
getPortalVars
getAlphabloxVars
ABX_THEME_HOME=$ABX_HOME/repository/theme

# clean/setup logs directory
if [ -e  $MY_DIR/install ] 
then 
 rm -rf $MY_DIR/install
fi 
mkdir -p $LOGS


echo backup $PROFILE_NAME WAS configuration...
CMD="$PROFILE_HOME/bin/backupConfig.sh -profileName $PROFILE_NAME -username $ADMIN_ID -password $ADMIN_PW"
$CMD >$LOGS/backupconfig.log 2>&1
checkCmdErr $?

copyFiles

echo starting server $PORTAL_SERVER...
CMD="$PROFILE_HOME/bin/startServer.sh $PORTAL_SERVER -username $ADMIN_PW -password $ADMIN_PW"
$CMD >$LOGS/startServer.log 2>&1 
checkCmdErr $?

# deploy wbimon
echo deploying WBIMon...
CMD="$WPS_HOME/bin/xmlaccess.sh -in scripts/update_WBIMon.xml -user $ADMIN_ID -pwd $ADMIN_PW -url $CONFIG_URL" 
$CMD >$LOGS/update_WBIMon.out 2>&1
checkCmdErr $?

# deploy theme
echo deploying Theme...
CMD="$WPS_HOME/bin/xmlaccess.sh -in scripts/Deploy_Theme.xml -user $ADMIN_ID -pwd $ADMIN_PW -url $CONFIG_URL" 
$CMD >$LOGS/Deploy_Theme.out 2>&1
checkCmdErr $?

if [ $SET_WPS_DEFAULT_THEME = "yes" ]
  then
    echo updating Theme...
    CMD="$WPS_HOME/bin/xmlaccess.sh -in scripts/Set_WPSTheme.xml -user $ADMIN_ID -pwd $ADMIN_PW -url $CONFIG_URL" 
    $CMD >$LOGS/Set_WPSTheme.out 2>&1
    checkCmdErr $?
fi 

if [ $SET_ABX_DEFAULT_THEME = "yes" ]
  then
    echo set alphablox theme...
    CMD="$WAS_HOME/java/bin/java -classpath files/dashboardtheme.jar com.ibm.wbimonitor.dashboard.theme.SetABXTheme $ABX_HOST $ABX_TELNET_PORT $ABX_ADMIN_ID $ABX_ADMIN_PW $ABX_THEME $MY_DIR" 
    $CMD >$LOGS/Set_abxTheme.out 2>&1
    myerr=$?
    echo setAbxTheme returned: $myerr >>$LOGS/Set_abxTheme.out
    # this seems to return -1 always
  fi
if ! [ -e $ABX_THEME_HOME.pdfreportBACKUP.properties ]
then
  # does not exist automatically on aix, only windows
  if [ -e $ABX_THEME_HOME/pdfreport.properties ]
  then 
    CMD="cp -f $ABX_THEME_HOME/pdfreport.properties $ABX_THEME_HOME/pdfreportBACKUP.properties"
    $CMD >>$COPYFILES_OUT 2>&1
    checkCmdErr $?
  fi
  CMD="cp -f $ABX_THEME_HOME/wbmonitor/pdfreport.properties $ABX_THEME_HOME/pdfreport.properties"
  $CMD >>$COPYFILES_OUT 2>&1
  checkCmdErr $?
fi

echo updating WelcomePage...
CMD="$WPS_HOME/bin/xmlaccess.sh -in scripts/SetWelcomePage.xml -user $ADMIN_ID -pwd $ADMIN_PW -url $CONFIG_URL" 
$CMD >$LOGS/SetWelcomePage.out 2>&1
checkCmdErr $?

echo stopping server $PORTAL_SERVER...
CMD="$PROFILE_HOME/bin/stopServer.sh $PORTAL_SERVER -username $ADMIN_PW -password $ADMIN_PW"
$CMD >$LOGS/stopServer.log 2>&1
checkCmdErr $?
finished 0




