#!/bin/sh

# ************************************************************************
#  Licensed Material - Property of IBM
# 
#  5724-M24
# 
#  (c) Copyright IBM Corp. 2006.  All rights reserved.
# 
#  US Government Users Restricted Rights - Use, duplication or
#  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
# ************************************************************************
# 
# ************************************************************************
#  Upgrade Monitor Server 6.0.0 to 6.0.1
# ************************************************************************

# ************************************************************************
# Begin function definitions
# ************************************************************************
# 
#  Manually "deploy" a WCCM plugin to the administrative console's EAR. 
#  You will need to execute "iscdeploy -restore" afterwards to complete
#  the deployment.
# 
#  USAGE:
#
#    manualISCDeploy pluginWAR pluginId jarPrefix
# 
#      pluginWAR  Path the the plugin's WAR file
#      pluginId   The plugin's Id
#      jarPrefix  Prefix added to the plugin's jars when deployed.
# 
#  The WAS_HOME environment variable must be set prior to invocation.
# ************************************************************************
manualISCDeploy ()
{
  PLUGIN_WAR=$1
  PLUGIN_ID=$2
  JAR_PREFIX=$3
  ADMINCONSOLE_WAR=${WAS_HOME}/systemApps/adminconsole.ear/adminconsole.war
  JAR_EXE=${WAS_HOME}/java/bin/jar

  echo Using the following settings:
  echo   PLUGIN_WAR       = $PLUGIN_WAR
  echo   PLUGIN_ID        = $PLUGIN_ID
  echo   JAR_PREFIX       = $JAR_PREFIX
  echo   WAS_HOME         = $WAS_HOME
  echo   ADMINCONSOLE_WAR = $ADMINCONSOLE_WAR
  echo   JAR_EXE          = $JAR_EXE

  # this script has to change directories to overcome limitations
  # in jar.exe, so I save the current directory name here
  SAVE_CD=`pwd`

  # change to the admin console's war directory
  cd $ADMINCONSOLE_WAR

  # extract NLS files
  $JAR_EXE xvf $PLUGIN_WAR $PLUGIN_ID
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract pre-compiled JSP files
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/classes
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract dependent jars to temp directory
  # create temp directory and change directory to it
  TEMP_DIR=/tmp/monitorUpgrade
  mkdir $TEMP_DIR
  cd $TEMP_DIR

  # extract jars
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/lib
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # rename jars
  cd WEB-INF/lib
  for file in *
  do
    mv $file ${JAR_PREFIX}-$file
  done

  # move jars
  mv * ${ADMINCONSOLE_WAR}/WEB-INF/lib
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # cleanup temp directory
  cd $SAVE_CD
  rm -r $TEMP_DIR
  
  # cd to plugin WEB-INF directory
  PLUGIN_WEBINF_DIR=${ADMINCONSOLE_WAR}/WEB-INF/${PLUGIN_ID}
  cd $PLUGIN_WEBINF_DIR

  # extract needed files and move to the correct location
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/console-defs.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.dtd
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_de.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_en.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_es.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_fr.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_it.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_ja.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_ko.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_pt.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_pt_BR.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_zh.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/plugin_zh_TW.properties
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/struts-config.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/validation.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi
  
  mv WEB-INF/* .
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # add needed file to com.ibm.ws.console.core plugin
  cp console-defs.xml ../com.ibm.ws.console.core/${PLUGIN_ID}-console-defs.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # extract web.xml
  $JAR_EXE xvf $PLUGIN_WAR WEB-INF/web.xml
  SAVE_RC=$?
  if [ $SAVE_RC -ne 0 ]
  then 
    return $SAVE_RC
  fi

  # restore original directory
  cd $SAVE_CD

  # return from manualISCDeploy
  return 0
}

# ************************************************************************
# Write messages to log file
# ************************************************************************
logecho ()
{
  echo "********************************************************" >> $MY_LOG 2>&1
  echo $1 >> $MY_LOG 2>&1
  echo "********************************************************" >> $MY_LOG 2>&1
  date >> $MY_LOG 2>&1
  return 0
}

# ************************************************************************
# Check return code from command execution
# ************************************************************************
checkCmdErr ()
{
  if [ $1 -ne 0 ]
  then 
    echo Error: command failed, return code = $1
    logecho "Error: command failed, return code = $1"
    echo Upgrade failed! 
    echo Upgrade failed! >> $MY_LOG 2>&1
    exit $1
  fi
  return 0
}
# ************************************************************************
# End function definitions
# ************************************************************************

# set up logs directory
MY_DIR=`pwd`
if [ ! -e  $MY_DIR/logs ] 
then 
   mkdir -p $MY_DIR/logs
fi 
MY_LOG=$MY_DIR/logs/monsrv.log

echo Start upgrade...
echo Start upgrade... > $MY_LOG 2>&1
date >> $MY_LOG 2>&1
echo "********************************************************" >> $MY_LOG 2>&1

# get WAS home dir 
WAS_HOME=/usr/IBM/WebSphere/ProcServer
echo Type the Process Server home directory [enter=$WAS_HOME ]: 
read input
if [ "$input" != "" ]
then
   WAS_HOME=$input
fi

if [ -e $WAS_HOME ]
then 
   echo $WAS_HOME exists >> $MY_LOG 2>&1
else
   echo $WAS_HOME does NOT exist!!!
   echo $WAS_HOME does NOT exist!!! >> $MY_LOG 2>&1
   exit 1
fi

# get profile dir                  
WAS_PROFILE_HOME=/usr/IBM/WebSphere/ProcServer/profiles/monitor
echo Type the Process Server profile directory [enter=$WAS_PROFILE_HOME ]: 
read input
if [ "$input" != "" ]
then
   WAS_PROFILE_HOME=$input
fi

if [ -e $WAS_PROFILE_HOME ]
then 
   echo $WAS_PROFILE_HOME exists >> $MY_LOG 2>&1
else
   echo $WAS_PROFILE_HOME does NOT exist!!! 
   echo $WAS_PROFILE_HOME does NOT exist!!! >> $MY_LOG 2>&1
   exit 1
fi

# get cell name
cellName=`hostname -s`Node01Cell
echo Type the cell name [enter=$cellName ]: 
read input
if [ "$input" != "" ]
then
   cellName=$input
fi

if [ -e ${WAS_PROFILE_HOME}/config/cells/${cellName} ]
then 
   echo $cellName exists >> $MY_LOG 2>&1
else
   echo ${WAS_PROFILE_HOME}/config/cells/${cellName} does NOT exist!!! 
   echo ${WAS_PROFILE_HOME}/config/cells/${cellName} does NOT exist!!! >> $MY_LOG 2>&1
   exit 1
fi

# get node name           
nodeName=Node01
echo Type the node name [enter=$nodeName ]: 
read input
if [ "$input" != "" ]
then
   nodeName=$input
fi

if [ -e ${WAS_PROFILE_HOME}/config/cells/${cellName}/nodes/${nodeName} ]
then 
   echo $nodeName exists >> $MY_LOG 2>&1
else
   echo ${WAS_PROFILE_HOME}/config/cells/${cellName}/nodes/${nodeName} does NOT exist!!! 
   echo ${WAS_PROFILE_HOME}/config/cells/${cellName}/nodes/${nodeName} does NOT exist!!! >> $MY_LOG 2>&1
   exit 1
fi

# ************************************************************************
# copy jar files
# ************************************************************************
echo Stop server server1 ...
logecho "Stop server server1 ..."
. ${WAS_PROFILE_HOME}/bin/setupCmdLine.sh
sh ${WAS_PROFILE_HOME}/bin/stopServer.sh server1 >> $MY_LOG 2>&1

echo Copy jar files ... 
logecho "Copy jar files ..."
cp ./jars/*.jar ${WAS_HOME}/lib >> $MY_LOG 2>&1
checkCmdErr $?

cp ./files/MON.product ${WAS_HOME}/properties/version >> $MY_LOG 2>&1
checkCmdErr $?

# ************************************************************************
# update enterprise applications
# can't use 'update <appName> app' because we'll lose the imported models
# ************************************************************************
echo Update Monitor Server application ... 
logecho "Update Monitor Server application ..."
curdir=`pwd`
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_MONITOR_SERVER file {-operation update -contents ${curdir}/earfiles/adminservices.jar -contenturi adminservices.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_MONITOR_SERVER file {-operation update -contents ${curdir}/jars/bom.jar -contenturi bom.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_MONITOR_SERVER file {-operation update -contents ${curdir}/jars/DDbE.jar -contenturi DDbE.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_MONITOR_SERVER file {-operation update -contents ${curdir}/earfiles/eventrouter.jar -contenturi eventrouter.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
# use 'update <appName> modulefile' because we need to generate deployed code
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_MONITOR_SERVER modulefile {-operation update -contents ${curdir}/earfiles/observationmgr.jar -contenturi observationmgr.jar -deployejb}" >> $MY_LOG 2>&1
checkCmdErr $?

echo Update Action Manager application ... 
logecho "Update Action Manager application ..."
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER file {-operation update -contents ${curdir}/earfiles/monAAMCatalog.jar -contenturi monAAMCatalog.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER file {-operation update -contents ${curdir}/earfiles/monAAMCommon.jar -contenturi monAAMCommon.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER file {-operation update -contents ${curdir}/earfiles/monAAMController.jar -contenturi monAAMController.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER file {-operation update -contents ${curdir}/earfiles/monAAMDetermination.jar -contenturi monAAMDetermination.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER file {-operation update -contents ${curdir}/earfiles/monAAMHandler.jar -contenturi monAAMHandler.jar}" >> $MY_LOG 2>&1
checkCmdErr $?
# use 'update <appName> modulefile' because we need to generate deployed code
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER modulefile {-operation update -contents ${curdir}/earfiles/monAAMMDB.jar -contenturi monAAMMDB.jar -deployejb}" >> $MY_LOG 2>&1
checkCmdErr $?
sh ${WAS_PROFILE_HOME}/bin/wsadmin.sh -conntype NONE -c "\$AdminApp update IBM_WB_ACTIONMANAGER modulefile {-operation update -contents ${curdir}/earfiles/monAAMBootstrap.jar -contenturi monAAMBootstrap.jar -deployejb}" >> $MY_LOG 2>&1
checkCmdErr $?

# ************************************************************************
# update admin console plugins
# ************************************************************************
echo Update Admin Console ...
logecho "Update Admin Console ..."
  
# extract the Monitor Server plugin
echo Extracting the Monitor Server Admin Console plugin...
logecho "Extracting the Monitor Server Admin Console plugin..."
manualISCDeploy ${curdir}/files/monitor_admin_server.war com.ibm.ws.console.monitor.server wbimonitorserver >> $MY_LOG 2>&1
checkCmdErr $?

# extract the Action Manager plugin
echo Extracting the Action Manager Admin Console plugin...
logecho "Extracting the Action Manager Admin Console plugin..."
manualISCDeploy ${curdir}/files/monAAMAdmin.war com.ibm.ws.console.monitor.actionmgr actionmanager >> $MY_LOG 2>&1
checkCmdErr $?

# extract the Schema Generator plugin
echo Extracting the Schema Generator Admin Console plugin...
logecho "Extracting the Schema Generator Admin Console plugin..."
manualISCDeploy ${curdir}/files/monSGAdmin.war com.ibm.ws.console.monitor.schemagen SchemaGenerator >> $MY_LOG 2>&1
checkCmdErr $?

# execute iscdeploy to merge the plugin configuration files
echo Executing iscdeploy...
logecho "Executing iscdeploy..."
sh ${WAS_PROFILE_HOME}/bin/iscdeploy.sh -restore >> $MY_LOG 2>&1
checkCmdErr $?
echo End updating Admin Console plugins
logecho "End updating Admin Console plugins"

# ************************************************************************
# Restart the server
# ************************************************************************
echo Start server server1 ...
logecho "Start server server1 ..."
sh ${WAS_PROFILE_HOME}/bin/startServer.sh server1 >> $MY_LOG 2>&1
checkCmdErr $?
echo Upgrade finished.
logecho "Upgrade finished."

exit 0
